# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to test using our own copy of File::Temp if the system one is too old
%global old_file_temp %(perl -MFile::Temp -e 'print (($File::Temp::VERSION < 0.20) ? 1 : 0);' 2>/dev/null || echo 0)

# Have to use List::MoreUtils rather than List::Util on old perls
%global old_list_util %(perl -MList::Util -e 'print (($List::Util::VERSION < 1.33) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-CPAN-Meta
Summary:	Distribution metadata for a CPAN dist
Version:	2.140640
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/CPAN-Meta/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DA/DAGOLDEN/CPAN-Meta-%{version}.tar.gz 
Source1:	File::Temp-0.22.pm
Patch0:		CPAN-Meta-2.140640-old-List::Util.patch
Patch1:		CPAN-Meta-2.140640-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
BuildArch:	noarch
# Build
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(CPAN::Meta::Requirements) >= 2.121
BuildRequires:	perl(CPAN::Meta::YAML) >= 0.008
BuildRequires:	perl(JSON::PP) >= 2.27200
%if %{old_list_util}
BuildRequires:	perl(List::MoreUtils)
%endif
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Parse::CPAN::Meta) >= 1.4414
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(version) >= 0.88
# Main test suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Dir)
BuildRequires:	perl(Test::More)
# Extra tests (not run when bootstrapping due to multiple circular dependencies)
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Version) >= 0.04
%endif

%description
Software distributions released to the CPAN include a META.json or, for
older distributions, META.yml, which describes the distribution, its
contents, and the requirements for building and installing the
distribution. The data structure stored in the META.json file is described
in CPAN::Meta::Spec.

%prep
%setup -q -n CPAN-Meta-%{version}

# Have to use List::MoreUtils rather than List::Util on old perls
%if %{old_list_util}
%patch0
%endif

# Patch test suite to work with old Test::More version if necessary
%if %{old_test_more}
%patch1
%endif

# Use our own File::Temp for testing if the system one is too old
%if %{old_file_temp}
mkdir -p testlib/File
cp -p %{SOURCE1} testlib/File/Temp.pm
%endif

%build
%if %{old_file_temp}
export PERL5LIB=$(pwd)/testlib
%endif
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
%if %{old_file_temp}
export PERL5LIB=$(pwd)/testlib
%endif
make test
%if 0%{!?perl_bootstrap:1}
make test TEST_FILES="$(echo $(find xt/ -name '*.t' | grep -Fv xt/author/pod-spell.t ))"
%endif

%files
%defattr(-,root,root,-)
%doc Changes CONTRIBUTING history LICENSE README Todo
%{perl_vendorlib}/CPAN/
%{_mandir}/man3/CPAN::Meta.3pm*
%{_mandir}/man3/CPAN::Meta::Converter.3pm*
%{_mandir}/man3/CPAN::Meta::Feature.3pm*
%{_mandir}/man3/CPAN::Meta::History.3pm*
%{_mandir}/man3/CPAN::Meta::Prereqs.3pm*
%{_mandir}/man3/CPAN::Meta::Spec.3pm*
%{_mandir}/man3/CPAN::Meta::Validator.3pm*

%changelog
* Wed Mar  5 2014 Paul Howarth <paul@city-fan.org> - 2.140640-1
- Update to 2.140640
  - Added a 'load_string' method that guesses whether the string is YAML or
    JSON
- Update patches as needed

* Wed Dec  4 2013 Paul Howarth <paul@city-fan.org> - 2.133380-1
- Update to 2.133380
  - Improved bad version handling during META conversion
  - When downgrading multiple licenses to version 1.x META formats, if all the
    licenses are open source, the downgraded license will be "open_source", not
    "unknown"
- Add patch to support building with List::Util < 1.33 by using List::MoreUtils
  instead, currently needed everywhere since even Rawhide only has List::Util
  1.31 at the moment
- Update patch for building with old Test::More versions

* Fri Oct 11 2013 Paul Howarth <paul@city-fan.org> - 2.132830-1
- Update to 2.132830
  - CPAN::Meta::Prereqs now has a 'merged_requirements' method for combining
    requirements across multiple phases and types
  - Invalid 'meta-spec' is no longer a fatal error: instead, it will usually
    be treated as spec version "1.0" (prior to formalization of the meta-spec
    field); conversion has some heuristics for guessing a version depending on
    other fields if 'meta-spec' is missing or invalid
- Update patch for building with old Test::More versions

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.132661-1
- Update to 2.132661
  - Updated Makefile.PL logic to support PERL_NO_HIGHLANDER
  - Dropped ExtUtils::MakeMaker configure_requires dependency to 6.17
- Drop redundant patch for building with ExtUtils::MakeMaker < 6.30

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.132660-1
- Update to 2.132660
  - Installation on Perls < 5.12 will uninstall older versions installed
    due to being bundled with ExtUtils::MakeMaker
- Update patches as needed

* Thu Sep 19 2013 Paul Howarth <paul@city-fan.org> - 2.132620-1
- Update to 2.132620
  - META validation used to allow a scalar value when a list (i.e. array
    reference) was required for a field; this has been tightened and
    validation will now fail if a scalar value is given

* Sun Sep  8 2013 Paul Howarth <paul@city-fan.org> - 2.132510-1
- Update to 2.132510
  - Fixed incorrectly encoded META.yml

* Sat Aug  3 2013 Paul Howarth <paul@city-fan.org> - 2.132140-1
- Update to 2.132140
  - Fixed some typos in CPAN::Meta::Spec
  - Migrated repository to Perl-Toolchain-Gang organization on Github and
    updated metadata accordingly
- Drop BR: perl(Test::MinimumVersion), upstream test dropped
- Update patches as needed

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 2.131560-2
- Perl 5.18 rebuild

* Tue Jun 11 2013 Paul Howarth <paul@city-fan.org> - 2.131560-1
- Update to 2.131560
  - Replaced CPAN::Meta SYNOPSIS with code that actually works

* Wed May 29 2013 Paul Howarth <paul@city-fan.org> - 2.131490-1
- Update to 2.131490
  - Downconversion of custom resources was not dropping the leading "x_"; now,
    "x_MailingList" will downconvert correctly to "MailingList"
  - Per the Lancaster Consensus, the 'file' subkey of a package listed in
    'provides' must refer to an actual file in the distribution, either the .pm
    file that provides the package or another file (*.PL) that generates it
- Update patch for building with old Test::More versions

* Fri Mar 29 2013 Paul Howarth <paul@city-fan.org> - 2.130880-1
- Update to 2.130880
  - Fix provides 'version' bug introduced in the 2.130870 fix

* Thu Mar 28 2013 Paul Howarth <paul@city-fan.org> - 2.130870-1
- Update to 2.130870
  - Don't add 'version' to 'provides' during conversion if one didn't exist in
    the original
- Don't bother running the spelling test as Test::Spelling seems unable to cope
  with UTF-8 encoded names in POD; also drop the associated buildreqs
- Package new CONTRIBUTING file
- No longer need Test::Requires or the associated patch
- BR: perl(File::Spec::Functions) and perl(List::Util) for the new prereqs test
- BR: perl(Test::MinimumVersion) for new release test
- Specify version requirements for perl(Test::Pod) and perl(Test::Pod::Coverage)

* Thu Aug 23 2012 Paul Howarth <paul@city-fan.org> - 2.120921-4
- Don't run extra tests when bootstrapping

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 2.120921-3
- BR: perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 2.120921-1
- update to 2.120921
  - CPAN::Meta::Requirements has been split out into its own distribution so it
    can be used by CPAN.pm without requiring all of CPAN::Meta

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 2.120920-1
- update to 2.120920
  - CPAN::Meta::Requirements now has a 'requirements_for_module' method to
    retrieve a version requirements string for a specific module
  - Parse::CPAN::Meta prerequisite bumped to 1.4403
  - JSON::PP prerequisites bumped to 2.27200
  - CPAN::Meta::YAML prerequisite bumped to 0.008
- update patch for building with old Test::More versions

* Fri Mar 30 2012 Paul Howarth <paul@city-fan.org> - 2.120900-1
- update to 2.120900
  - CPAN::Meta::Requirements now treats undef requirements given to
    from_string_hash() as '0' and warns about it; add_string_requirements()
    dies if it does not get a requirements string to parse
- update patches

* Sat Mar  3 2012 Paul Howarth <paul@city-fan.org> - 2.120630-1
- update to 2.120630
  - CPAN::Meta::Requirements now ensures that dotted-decimal versions are
    represented in normalized form when stringified, which fixes a
    regression in META conversion in 2.120620
- update patch for building with old Test::More versions

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 2.120620-1
- update to 2.120620
  - CPAN::Meta::Requirements::add_string_requirements now allows building a
    requirements specification piecemeal
  - Version range handling fixed (CPAN RT#75424)
  - CPAN::Meta::Converter handles bad version strings more gracefully,
    truncating alphanumerics and otherwise falling back to "0"; this is likely
    better than dropping a prerequisite or dying (CPAN RT#75427)
- BR: perl(File::Basename)
- update patch for building with old Test::More versions
- don't need to remove empty directories from buildroot
- drop support for distributions prior to FC-3
  - don't need to define %%{perl_vendorlib}
  - use DESTDIR rather than PERL_INSTALL_ROOT
  - never need to BR: aspell-en-gb
  - BR: perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
    and perl(Test::Perl::Critic) unconditionally

* Thu Feb 23 2012 Paul Howarth <paul@city-fan.org> - 2.120530-1
- update to 2.120530
  - dialed back perl prereq to 5.006
- add buildreqs for author tests and run the author tests:
  - aspell-en/aspell-en-gb
  - perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
  - perl(Pod::Wordlist::hanekomu)
  - perl(Test::Perl::Critic)
  - perl(Test::Requires)
  - perl(Test::Spelling)
- add patch for spell check test for words not in Fedora/RHEL dictionaries
- add patch to work around unavailability of Test::Requires on old releases
- update patches to apply cleanly

* Sat Feb  4 2012 Paul Howarth <paul@city-fan.org> - 2.120351-1
- update to 2.120351
  - work around a memory leak bug involving version objects in boolean context
- this release by DAGOLDEN -> update source URL
- drop redundant buildreq perl(Test::Requires) and patch to work around not
  having it if necessary

* Sat Dec 31 2011 Paul Howarth <paul@city-fan.org> - 2.113640-1
- update to 2.113640
  - Version::Requirements has now been merged as CPAN::Meta::Requirements,
    rendering Version::Requirements itself redundant
- this release by RJBS -> update source URL
- drop BR: perl(Version::Requirements)
- BR: perl(Test::Requires)
- don't attempt to run author tests as they fail
- update patch for building with Test::More < 0.88
- add patch for building without Test::Requires if necessary

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> - 2.112621-1
- update to 2.112621
  - spell BACKEND environment variables correctly this time

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> - 2.112620-1
- update to 2.112620
  - protect tests against PERL_(YAML|JSON)_BACKEND settings that could cause
    tests to fail (CPAN RT#69979)

* Sat Sep 17 2011 Paul Howarth <paul@city-fan.org> - 2.112600-1
- update to 2.112600
  - fixed spelling error in CPAN::Meta::Spec (CPAN RT#71036)

* Wed Sep 14 2011 Paul Howarth <paul@city-fan.org> - 2.112580-1
- update to 2.112580
  - use UTF-8 mode for internal structure cloning to avoid bugs in
    Perl ≤ 5.8.6 (CPAN RT#70936)
- update patches

* Wed Aug  3 2011 Paul Howarth <paul@city-fan.org> - 2.112150-1
- update to 2.112150
  - stringify any objects encountered during conversion (CPAN RT#67295)
  - fixed some broken URLs in documentation and for LGPL in legacy
    conversion (CPAN RT#68738)
  - fixed invalid private Pod in CPAN::Meta::Validator (CPAN RT#65925)
  - clarified that file paths in the 'provides' section must be in
    Unix-style (i.e. forward slashes) (CPAN RT#69045)
  - replaced examples using Module::Build::ModuleInfo with Module::Metadata
    (CPAN RT#66135)
  - new test build requirements:
    - perl(Pod::Coverage::TrustPod)
    - perl(Test::CPAN::Meta)
    - perl(Test::Pod::Coverage)
    - perl(Test::Portability::Files)
    - perl(Test::Version) ≥ 0.04
- updated patches
- drop note about CentOS 3 64-bit build failing as it seems to work now

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 2.110930-2
- rebuild for perl 5.14.1 in Rawhide
- fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> - 2.110930-1
- update to 2.110930
  - the 1.x spec "gpl" and "lgpl" and "mozilla" license values now up-convert
    to "open_source" because they indicate too non-specific a license
  - fixed a bug in the 'as_string' method that checked the module version
    instead of the meta-spec version when conversion was requested
    (CPAN RT#67188)
- update patch for building with old Test::More versions
- nobody else likes macros for commands

* Mon Feb 28 2011 Paul Howarth <paul@city-fan.org> - 2.110580-1
- update to 2.110580
  - add explicit dependencies on JSON::PP and CPAN::Meta::YAML instead
    of relying on Parse::CPAN::Meta to provide them (as some CPAN Testers
    have had P::C::M installed without them somehow)
  - removed dependency on Storable as it was not a core module
    until Perl 5.8

* Fri Feb 25 2011 Paul Howarth <paul@city-fan.org> - 2.110550-1
- update to 2.110550
  - added required field 'release_status' to the synopsis of
    CPAN::Meta::Spec (CPAN RT#66118)

* Thu Feb 24 2011 Paul Howarth <paul@city-fan.org> - 2.110540-1
- update to 2.110540
  - in the presence of both 'requires' and 'build_requires', only include
    'requires' to avoid confusing some installers

* Tue Feb 15 2011 Paul Howarth <paul@city-fan.org> - 2.110440-1
- update to 2.110440
  - the as_string() method now always returns a character string; previously,
    JSON strings were UTF-8 encoded
  - the save() method now always saves with UTF-8 encoding for Perl 5.8.1 or
    greater; previously, YAML was not encoded
  - bump Parse::CPAN::Meta prereq to 1.44, as 1.43 was never released

* Thu Feb 10 2011 Paul Howarth <paul@city-fan.org> - 2.110390-1
- import from Fedora
- update to 2.110390
- drop no-longer needed BR: perl(autodie) and perl(JSON)
- add patch to support building with ExtUtils::MakeMaker < 6.31
- add patch to support building with Test::More < 0.88
- use our own copy of File::Temp if the system one is < 0.20

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 2.102400-2
- rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 29 2010 Iain Arnell <iarnell@gmail.com> 2.102400-1
- update by Fedora::App::MaintainerTools 0.006
- updating to latest GA CPAN version (2.102400)
- added a new br on perl(Carp) (version 0)
- added a new br on perl(Data::Dumper) (version 0)
- altered br on perl(ExtUtils::MakeMaker) (0 => 6.31)
- added a new br on perl(File::Spec) (version 0)
- added a new br on perl(File::Temp) (version 0.20)
- added a new br on perl(IO::Dir) (version 0)
- added a new br on perl(Scalar::Util) (version 0)
- added a new br on perl(Storable) (version 0)
- added a new br on perl(autodie) (version 0)
- added a new br on perl(version) (version 0.82)

* Thu Aug 05 2010 Iain Arnell <iarnell@gmail.com> 2.102160-1
- update to latest upstream

* Wed Jun 16 2010 Iain Arnell <iarnell@gmail.com> 2.101670-1
- update to latest upstream

* Mon Jun 14 2010 Iain Arnell <iarnell@gmail.com> 2.101610-1
- update to latest upstream

* Tue Jun 01 2010 Iain Arnell <iarnell@gmail.com> 2.101461-2
- rebuild for perl-5.12

* Fri May 28 2010 Iain Arnell <iarnell@gmail.com> 2.101461-1
- Specfile autogenerated by cpanspec 1.78.
- drop explicit requirements
